@@ -24,7 +24,7 @@ from tg.decorators import (
 
 from allura.controllers import BaseController
 from allura.lib import helpers as h
-from allura.lib.decorators import require_post, task
+from allura.lib.decorators import require_post
 from allura.lib.plugin import ImportIdConverter
 from allura import model as M
 
@@ -34,7 +34,6 @@ from forgewiki import model as WM
 from forgeimporters.base import (
         ToolImporter,
         ToolImportForm,
-        ImportErrorHandler,
         )
 from forgeimporters.google import GoogleCodeProjectExtractor
 
@@ -43,12 +42,7 @@ DATE_FORMAT = '%a %b %d %H:%M:%S %Y'
 
 log = logging.getLogger(__name__)
 
-
-@task(notifications_disabled=True)
-def import_tool(**kw):
-    importer = GoogleCodeWikiImporter()
-    with ImportErrorHandler(importer, kw.get('project_name'), c.project):
-        importer.import_tool(c.project, c.user, **kw)
+html2text.BODY_WIDTH = 0
 
 
 class GoogleCodeWikiImportForm(ToolImportForm):
@@ -74,8 +68,8 @@ class GoogleCodeWikiImportController(BaseController):
     @require_post()
     @validate(GoogleCodeWikiImportForm(ForgeWikiApp), error_handler=index)
     def create(self, gc_project_name, mount_point, mount_label, **kw):
-        if GoogleCodeWikiImporter().enforce_limit(c.project):
-            import_tool.post(
+        if self.importer.enforce_limit(c.project):
+            self.importer.post(
                     project_name=gc_project_name,
                     mount_point=mount_point,
                     mount_label=mount_label,
