@@ -256,7 +256,7 @@ class TestGoogleCodeWikiImportController(TestController, TestCase):
         self.assertIsNotNone(r.html.find(attrs=dict(name="mount_point")))
 
     @with_wiki
-    @patch('googlecodewikiimporter.importer.import_tool')
+    @patch('forgeimporters.base.import_tool')
     def test_create(self, import_tool):
         params = dict(gc_project_name='myproject',
                 mount_label='mylabel',
@@ -270,7 +270,7 @@ class TestGoogleCodeWikiImportController(TestController, TestCase):
         self.assertEqual(u'myproject', import_tool.post.call_args[1]['project_name'])
 
     @with_wiki
-    @patch('googlecodewikiimporter.importer.import_tool')
+    @patch('forgeimporters.base.import_tool')
     def test_create_limit(self, import_tool):
         project = M.Project.query.get(shortname='test')
         project.set_tool_data('GoogleCodeWikiImporter', pending=1)
